==> risecx_chat_client-1.1.1.tar.gz: lib/widgets/chat/chat-client.dart <==
import 'package:flutter/material.dart';
import 'package:risecx_chat_client/blocs/blocs.dart';
import 'package:risecx_chat_client/models/configuration_model.dart';
import 'package:risecx_chat_client/models/messages/commons/commons.dart';
import 'package:risecx_chat_client/models/models.dart';
import 'package:risecx_chat_client/widgets/chat/action-bar.dart';
import 'package:risecx_chat_client/widgets/widgets.dart';
import 'package:url_launcher/url_launcher.dart';
import 'message-input.dart';
import 'message-list.dart';

class ChatClientWidget extends StatefulWidget {
  final ChatBloc chatBloc;
  final UserModel user;
  final ConfigurationModel config;
  final Map<String, dynamic> initConversationTrigger;
  ChatClientWidget(
      {this.chatBloc, this.user, this.config, this.initConversationTrigger});
  @override
  ChatClientState createState() => ChatClientState();
}

class ChatClientState extends State<ChatClientWidget>
    with AutomaticKeepAliveClientMixin {
  final TextEditingController _textEditingController =
      new TextEditingController();

  @override
  void initState() {
    super.initState();
    if (widget.initConversationTrigger != null) {
      if (widget.initConversationTrigger["type"] == "payload")
        _onPostback(widget.initConversationTrigger['text'],
            widget.initConversationTrigger['key']);
      else {
        final SendMessageModel message = new SendMessageModel(
            text: widget.initConversationTrigger['text'], user: widget.user.id);
        widget.chatBloc.sendMessage(message);
      }
    }
    // widget.chatBloc.userIdentifier(widget.user);
  }

  void _onFavorite(selectedMessage) {
    widget.chatBloc.addOrRemoveFavoriteMessage(selectedMessage, true);
    widget.chatBloc.selectMessageToggle(selectedMessage);
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.only(bottom: 8),
      child: Column(
        children: <Widget>[
          Expanded(
              child: ActionBar(
            bloc: widget.chatBloc,
            actions: <ActionBarButton>[
              ActionBarButton(icon: Icon(Icons.star), onPressed: _onFavorite)
            ],
          )),
          Expanded(
            flex: 9,
            child: MessageList(
                chatBloc: widget.chatBloc,
                onPayloadPress: _onPayloadPress,
                onMediaView: _onMediaViewHandler),
          ),
          Expanded(
            child: MessageInput(
                chatBloc: widget.chatBloc,
                textEditingController: _textEditingController,
                onPressed: _sendMessage,
                onQuickMenuSelect: _onQuickMenuSelectHandler),
          )
        ],
      ),
    );
  }

  void _sendMessage() {
    if (_textEditingController.text.isNotEmpty) {
      final SendMessageModel message = new SendMessageModel(
          text: _textEditingController.text, user: widget.user.id);
      widget.chatBloc.sendMessage(message);

      _textEditingController.clear();
    }
  }

  void _onPayloadPress(dynamic button) {
    if (button is Buttons) {
      if (button.type == 'web_url')
        this._onWebUrl(button.url);
      else
        this._onPostback(button.title, button.payload);
    }
    if (button is QuickReplies) {
      this._onPostback(button.title, button.payload);
    }
  }

  void _onPostback(title, payload) {
    final SendMessageModel message =
        new SendMessageModel(text: title, user: widget.user.id);
    widget.chatBloc.onPostBack(message, title, payload);
  }

  void _onWebUrl(url) async {
    if (await canLaunch(url)) {
      await launch(url);
    } else {
      throw 'Could not launch $url';
    }
  }

  void _onQuickMenuSelectHandler(QuickMenuItemModel item) {
    if (item.url != null && item.url.isNotEmpty) this._onWebUrl(item.url);
    if (item.payload != null) this._onPostback(item.name, item.payload);
  }

  void _onMediaViewHandler(String url, String blockId, String sessionId) {
    widget.chatBloc
        .onMediaView(url: url, blockId: blockId, sessionId: sessionId);
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  bool get wantKeepAlive => true;
}

==> risecx_chat_client-1.2.1.tar.gz: lib/widgets/chat/chat-client.dart <==
import 'package:flutter/material.dart';
import 'package:risecx_chat_client/blocs/blocs.dart';
import 'package:risecx_chat_client/models/configuration_model.dart';
import 'package:risecx_chat_client/models/messages/commons/commons.dart';
import 'package:risecx_chat_client/models/models.dart';
import 'package:risecx_chat_client/widgets/chat/action-bar.dart';
import 'package:risecx_chat_client/widgets/widgets.dart';
import 'package:url_launcher/url_launcher.dart';
import 'message-input.dart';
import 'message-list.dart';

class ChatClientWidget extends StatefulWidget {
  final ChatBloc chatBloc;
  final UserModel user;
  final ConfigurationModel config;
  final Map<String, dynamic> initConversationTrigger;
  ChatClientWidget(
      {this.chatBloc, this.user, this.config, this.initConversationTrigger});
  @override
  ChatClientState createState() => ChatClientState();
}

class ChatClientState extends State<ChatClientWidget>
    with AutomaticKeepAliveClientMixin {
  final TextEditingController _textEditingController =
      new TextEditingController();

  @override
  void initState() {
    super.initState();
    if (widget.initConversationTrigger != null) {
      if (widget.initConversationTrigger["type"] == "payload")
        _onPostback(widget.initConversationTrigger['text'],
            widget.initConversationTrigger['key']);
      else {
        final SendMessageModel message = new SendMessageModel(
            text: widget.initConversationTrigger['text'], user: widget.user.id);
        widget.chatBloc.sendMessage(message);
      }
    }
    // widget.chatBloc.userIdentifier(widget.user);
  }

  void _onFavorite(selectedMessage) {
    widget.chatBloc.addOrRemoveFavoriteMessage(selectedMessage, true);
    widget.chatBloc.selectMessageToggle(selectedMessage);
  }

  @override
  Widget build(BuildContext context) {
    return StreamBuilder(
      stream: widget.chatBloc.messagesListStream,
      builder: (BuildContext context, AsyncSnapshot snapshot) {
        return Container(
          // padding: EdgeInsets.only(bottom: 4),
          child: Column(
              children: <Widget>[
              (snapshot.data is List && snapshot.data[snapshot.data.length - 1]['type'] == 'typing') ?
                Padding(
                  child: Text(
                  'Typing...',
                  textAlign: TextAlign.left,
                  overflow: TextOverflow.ellipsis,
                  style: TextStyle(fontWeight: FontWeight.bold),
                ),
                padding: EdgeInsets.all(24),
              ) : Expanded(
                  child: ActionBar(
                bloc: widget.chatBloc,
                actions: <ActionBarButton>[
                  ActionBarButton(icon: Icon(Icons.star), onPressed: _onFavorite)
                ],
              )),
              Expanded(
                flex: 9,
                child: MessageList(
                    chatBloc: widget.chatBloc,
                    onPayloadPress: _onPayloadPress,
                    onMediaView: _onMediaViewHandler),
              ),
              Expanded(
                child: MessageInput(
                    chatBloc: widget.chatBloc,
                    textEditingController: _textEditingController,
                    onPressed: _sendMessage,
                    onQuickMenuSelect: _onQuickMenuSelectHandler),
              )
            ],
          ),
        );
      });
  }

  void _sendMessage() {
    if (_textEditingController.text.isNotEmpty) {
      final SendMessageModel message = new SendMessageModel(
          text: _textEditingController.text, user: widget.user.id);
      widget.chatBloc.sendMessage(message);

      _textEditingController.clear();
    }
  }

  void _onPayloadPress(dynamic button) {
    if (button is Buttons) {
      if (button.type == 'web_url')
        this._onWebUrl(button.url);
      else
        this._onPostback(button.title, button.payload);
    }
    if (button is QuickReplies || button is Menus) {
      this._onPostback(button.title, button.payload);
    }
  }

  void _onPostback(title, payload) {
    final SendMessageModel message =
        new SendMessageModel(text: title, user: widget.user.id);
    widget.chatBloc.onPostBack(message, title, payload);
  }

  void _onWebUrl(url) async {
    if (await canLaunch(url)) {
      await launch(url);
    } else {
      throw 'Could not launch $url';
    }
  }

  void _onQuickMenuSelectHandler(QuickMenuItemModel item) {
    if (item.url != null && item.url.isNotEmpty) this._onWebUrl(item.url);
    if (item.payload != null) this._onPostback(item.name, item.payload);
  }

  void _onMediaViewHandler(String url, String blockId, String sessionId) {
    widget.chatBloc
        .onMediaView(url: url, blockId: blockId, sessionId: sessionId);
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  bool get wantKeepAlive => true;
}
